# Script for analyzing the individual
# csv data files from the Lab 3 Stroop Effect Experiment
#
# Lew Harvey
# 5 October 2015
#
# Note:
#   This script expects that the these three columns exist in the data file:
#   1. resp.rt (the reaction time in second of each response)
#   2. resp.corr (1 indicates a correct response; 0 indicates an incorrect response)
#   3. congruent (a factor with two values: "cong" and "incong")

# Part 1: Data Preparation
#####################################################################################
# load needed libraries
library("bootES")

# define and read in the data file
fn <- file.choose()
df.raw <- read.csv(fn)

# clean up data frame
df.raw$X <- NULL

# eliminate the practice trials
df <- subset(df.raw, !is.na(df.raw$trials.thisTrialN))

# add a column for the log of the response reaction time
df$log.resp.rt <- log(df$resp.rt)

# eliminate the incorrect trials
# comment out this line if you want to analyze both correct and incorrect trials
# df <- subset(df, df$resp.corr > 0)

# Part 2: Compute the bootstrap confidence intervals and linear models
#####################################################################################
# compute the confidence intervals of congruient and incongruent group effects
# for linear reaction time
bs.lin <- bootES(data = df, R = 5000,
                 effect.type = "unstandardized",
                 data.col = "resp.rt", 
                 group.col = "congruent",
                 contrast = c(cong = -1, incong = 1))

# Replace XXXXX with a bootES command that computes the standardized effect size (HINT: "cohens.d")
bs.lin.d <- XXXXX

# compute the confidence intervals congruient and incongruent group effects for the log of reaction time
# Replace XXXXX with the appropriate data column (i.e., DV)
# Replace YYYYY with the appropriate grouping column (i.e., IV)
# Replace ZZ and ZZ with the contrast codes (must sum to 0).
bs.log <- bootES(data = df, R = 5000,
                 effect.type = "unstandardized",
                 data.col = "XXXXX", 
                 group.col = "YYYYY",
                 contrast = c(cong = ZZ, incong = ZZ))

# Replace XXXXX with a bootES command that computes the standardized effect size on the log of the RT (HINT: "cohens.d")
bs.log.d <- XXXXX

# compute a linear model of the congruence effect on reaction time.
# Replace YYYYY with the DV column
# Replace XXXXX with the IV column
mod.lin <- lm(YYYYY ~ XXXXX, data = df)

# compute a linear model of the congruence effect on log reaction time
# Replace YYYYY with the DV column (log transformed)
# Replace XXXXX with the IV column
mod.log <- lm(YYYYY ~ XXXXX, data = df)

cat("\n")
print("linear reaction time model")
print(anova(mod.lin))
cat("\n")
print("log raaction time model")
print(anova(mod.log))

# Part 3: Plotting Section
#####################################################################################
# define plot functions

# strip plot of reaction times
plot1a <- function() {
    stripchart(resp.rt ~ congruent, data = df, vertical = TRUE,
               xlim = c(0.5, 2.5),
               xlab = "Color-Word Congruity",
               ylab = "Reaction Time in Seconds",
               main = "Linear RT Group Effect")
}
# box plot of reaction times
plot1b <- function() {
    boxplot(resp.rt ~ congruent, data = df, col = "yellow",
            xlab = "Color-Word Congruity",
            ylab = "Reaction Time in Seconds",
            main = "Linear RT Group Effect")
}
# box plot of bootstrap linear reaction time unstandardized effect size
plot1c <- function() {
    boxplot(bs.lin$t, col = "yellow",
            xlab = "Color-Word Congruity",
            ylab = "Unstandardized Effect Size",
            main = "Unstandardized Effect Size")
    abline(h = bs.lin$bounds, col = "gray")
    abline(h = 0, col = "red")
    abline(h = bs.lin$t0, col = "gray")
    text(0.65, bs.lin$bounds[1], "lower confidence limit", pos = 3, cex = 0.5)
    text(0.65, bs.lin$bounds[2], "upper confidence limit", pos = 3, cex = 0.5)
}
# box plot of bootstrap linear reaction time standardized effect size
plot1d <- function() {
    boxplot(bs.lin.d$t, col = "yellow",
            xlab = "Color-Word Congruity",
            ylab = "Cohen's d Effect Size",
            main = "Standardized Effect Size")
    abline(h = bs.lin.d$bounds, col = "gray")
    abline(h = 0, col = "red")
    abline(h = bs.lin.d$t0, col = "gray")
    text(0.65, bs.lin.d$bounds[1], "lower confidence limit", pos = 3, cex = 0.5)
    text(0.65, bs.lin.d$bounds[2], "upper confidence limit", pos = 3, cex = 0.5)
}

# strip plot of log reaction times
plot1e <- function() {
    stripchart(log.resp.rt ~ congruent, data = df, vertical = TRUE,
               xlim = c(0.5, 2.5),
               xlab = "Color-Word Congruity",
               ylab = "Reaction Time in Log Seconds",
               main = "Log RT Group Effect")
}
# box plot of log reaction times
plot1f <- function() {
    boxplot(log.resp.rt ~ congruent, data = df, col = "yellow",
            xlab = "Color-Word Congruity",
            ylab = "Reaction Time in Log Seconds",
            main = "Log RT Group Effect")
}
# box plot of bootstrap log reaction time effect size
plot1g <- function() {
    boxplot(bs.log$t, col = "yellow",
            xlab = "Color-Word Congruity",
            ylab = "Cohen's d Effect Size",
            main = "Unstandardized Effect Size")
    abline(h = 0, col = "red")
    abline(h = bs.log$bounds, col = "gray")
    abline(h = bs.log$t0, col = "gray")
    text(0.65, bs.log$bounds[1], "lower confidence limit", pos = 3, cex = 0.5)
    text(0.65, bs.log$bounds[2], "upper confidence limit", pos = 3, cex = 0.5)
}
# box plot of bootstrap log reaction time effect size
plot1h <- function() {
    boxplot(bs.log.d$t, col = "yellow",
            xlab = "Color-Word Congruity",
            ylab = "Cohen's d Effect Size",
            main = "Standardized Effect Size")
    abline(h = 0, col = "red")
    abline(h = bs.log.d$bounds, col = "gray")
    abline(h = bs.log.d$t0, col = "gray")
    text(0.65, bs.log.d$bounds[1], "lower confidence limit", pos = 3, cex = 0.5)
    text(0.65, bs.log.d$bounds[2], "upper confidence limit", pos = 3, cex = 0.5)
}

par(mfrow = c(2, 4))
plot1a()
plot1b()
plot1c()
plot1d()
plot1e()
plot1f()
plot1g()
plot1h()
par(mfrow = c(1,1))
